@@ -26,18 +26,17 @@
 #include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
 
+#ifdef ENABLE_GNOME
 #include <libgnomeui/libgnomeui.h>
 #include <libgnome/gnome-program.h>
 #include <libgnome/gnome-help.h>
+#endif
 
 #include <string.h>
 
 #include "gst-tool.h"
 #include "gst-dialog.h"
-#include "gst-report-line.h"
-#include "gst-report-hook.h"
 #include "gst-platform-dialog.h"
-#include "gst-ui.h"
 #include "gst-marshal.h"
 
 
@@ -56,15 +55,6 @@ enum {
 	PLATFORM_LIST_COL_LAST
 };
 
-enum {
-	UPDATE_GUI,
-	UPDATE_CONFIG,
-	CLOSE,
-	LAST_SIGNAL
-};
-
-static gint signals [LAST_SIGNAL] = { 0 };
-
 static void  gst_tool_class_init   (GstToolClass *class);
 static void  gst_tool_init         (GstTool      *tool);
 static void  gst_tool_finalize     (GObject      *object);
@@ -72,19 +62,12 @@ static void  gst_tool_finalize     (GObject      *object);
 static GObject* gst_tool_constructor (GType                  type,
 				      guint                  n_construct_properties,
 				      GObjectConstructParam *construct_params);
-
 static void  gst_tool_set_property (GObject      *object,
 				    guint         prop_id,
 				    const GValue *value,
 				    GParamSpec   *pspec);
 
-static void gst_tool_close         (GstTool *tool);
-
-static void gst_tool_create_platform_list        (GstTool *tool,
-						  GtkTreeView *list);
-static void gst_tool_populate_platform_list      (GstTool *tool);
-static const gchar* gst_tool_run_platform_dialog (GstTool *tool);
-
+static void gst_tool_impl_close    (GstTool *tool);
 
 
 enum {
@@ -118,7 +101,7 @@ gst_tool_class_init (GstToolClass *class)
 	object_class->constructor  = gst_tool_constructor;
 	object_class->finalize     = gst_tool_finalize;
 
-	class->close = gst_tool_close;
+	class->close = gst_tool_impl_close;
 	class->update_gui = NULL;
 	class->update_config = NULL;
 
@@ -143,31 +126,6 @@ gst_tool_class_init (GstToolClass *class)
 							      "Tool icon",
 							      NULL,
 							      G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	signals[UPDATE_GUI] =
-		g_signal_new ("update_gui",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GstToolClass, update_gui),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
-	signals[UPDATE_CONFIG] = 
-		g_signal_new ("update_config",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GstToolClass, update_config),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
-	signals[CLOSE] = 
-		g_signal_new ("close",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GstToolClass, close),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
-
 	g_type_class_add_private (object_class,
 				  sizeof (GstToolPrivate));
 }
@@ -207,43 +165,22 @@ gst_tool_init (GstTool *tool)
 		gdk_pixbuf_unref (pixbuf);
 
 	g_object_unref (xml);
-	
-	/* load the report window */
-	/* FIXME
-	xml = gst_tool_load_glade_common (tool, "report_window");
+}
 
-	tool->report_window = glade_xml_get_widget (xml, "report_window");
+static void
+show_access_denied_dialog (GstTool *tool)
+{
+	GtkWidget *dialog;
 
-	g_signal_connect (G_OBJECT (tool->report_window), "delete_event",
-			  G_CALLBACK (report_window_close_cb), tool);
-	*/
-/*
-	tool->report_label    = glade_xml_get_widget (xml, "report_label");
-	tool->report_progress = glade_xml_get_widget (xml, "report_progress");
-	tool->report_pixmap   = glade_xml_get_widget (xml, "report_pixmap");
-
-	pixbuf = gtk_icon_theme_load_icon (tool->icon_theme, "gnome-system-config", 48, 0, NULL);
-	gtk_image_set_from_pixbuf (GTK_IMAGE (tool->report_pixmap), pixbuf);
-	gdk_pixbuf_unref (pixbuf);
-*/
-
-	/* load the platforms list */
-	xml = gst_tool_load_glade_common (tool, "platform_dialog");
-	tool->platform_list = glade_xml_get_widget (xml, "platform_list");
-	gst_tool_create_platform_list (tool, GTK_TREE_VIEW (tool->platform_list));
-	gst_tool_populate_platform_list (tool);
-
-	tool->platform_dialog    = glade_xml_get_widget (xml, "platform_dialog");
-	tool->platform_ok_button = glade_xml_get_widget (xml, "platform_ok_button");
-	g_object_unref (xml);
-
-	/* load the remote config dialog */
-	/* FIXME
-	xml = gst_tool_load_glade_common (tool, "remote_dialog");
-	tool->remote_dialog = glade_xml_get_widget (xml, "remote_dialog");
-	tool->remote_hosts_list = glade_xml_get_widget (xml, "remote_hosts_list");
-	gst_tool_create_remote_hosts_list (GTK_TREE_VIEW (tool->remote_hosts_list), tool);
-	*/
+	dialog = gtk_message_dialog_new (NULL,
+					 GTK_DIALOG_MODAL,
+					 GTK_MESSAGE_ERROR,
+					 GTK_BUTTONS_CLOSE,
+					 _("The configuration could not be loaded"));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  _("You are not allowed to access the system configuration."));
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 static GObject*
@@ -256,6 +193,7 @@ gst_tool_constructor (GType                  type,
 	gchar *widget_name;
 	const gchar *platform;
 	GtkWidget *dialog;
+	OobsResult result;
 
 	object = (* G_OBJECT_CLASS (gst_tool_parent_class)->constructor) (type,
 									  n_construct_properties,
@@ -276,10 +214,23 @@ gst_tool_constructor (GType                  type,
 		g_free (widget_name);
 	}
 
-	if (!oobs_session_get_platform (tool->session)) {
+	result = oobs_session_get_platform (tool->session, NULL);
+
+	switch (result) {
+	case OOBS_RESULT_NO_PLATFORM:
 		dialog = gst_platform_dialog_new (tool->session);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
+
+		gst_tool_update_config (tool);
+		break;
+	case OOBS_RESULT_ACCESS_DENIED:
+	case OOBS_RESULT_ERROR:
+		show_access_denied_dialog (tool);
+		exit (-1);
+		break;
+	default:
+		break;
 	}
 
 	return object;
@@ -314,7 +265,7 @@ gst_tool_finalize (GObject *object)
 }
 
 static void
-gst_tool_close (GstTool *tool)
+gst_tool_impl_close (GstTool *tool)
 {
 	/* FIXME: add things to do when closing the tool */
 	gtk_main_quit ();
@@ -323,7 +274,28 @@ gst_tool_close (GstTool *tool)
 void
 gst_tool_update_gui (GstTool *tool)
 {
-	g_signal_emit (G_OBJECT (tool), signals[UPDATE_GUI], 0, NULL);
+	g_return_if_fail (GST_IS_TOOL (tool));
+
+	if (GST_TOOL_GET_CLASS (tool)->update_gui)
+		(* GST_TOOL_GET_CLASS (tool)->update_gui) (tool);
+}
+
+void
+gst_tool_update_config (GstTool *tool)
+{
+	g_return_if_fail (GST_IS_TOOL (tool));
+
+	if (GST_TOOL_GET_CLASS (tool)->update_config)
+		(* GST_TOOL_GET_CLASS (tool)->update_config) (tool);
+}
+
+void
+gst_tool_close (GstTool *tool)
+{
+	g_return_if_fail (GST_IS_TOOL (tool));
+
+	if (GST_TOOL_GET_CLASS (tool)->close)
+		(* GST_TOOL_GET_CLASS (tool)->close) (tool);
 }
 
 
@@ -813,86 +785,6 @@ gst_tool_class_init (GstToolClass *class)
 }
 */
 
-static void
-gst_tool_create_platform_list (GstTool *tool, GtkTreeView *list)
-{
-	GtkTreeModel *model = GTK_TREE_MODEL (gtk_list_store_new (PLATFORM_LIST_COL_LAST, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_POINTER));
-	GtkCellRenderer *renderer;
-	GtkTreeViewColumn *column;
-	GtkTreeSelection *select;
-
-	g_return_if_fail (list != NULL);
-	g_return_if_fail (GTK_IS_TREE_VIEW (list));
-
-	gtk_tree_view_set_model (GTK_TREE_VIEW (list), model);
-	g_object_unref (model);
-	
-	/* Insert the pixmaps cell */
-	renderer = gtk_cell_renderer_pixbuf_new ();
-	g_object_set (G_OBJECT (renderer), "xalign", 0.0, NULL);
-
-	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (list),
-	                                             -1,
-	                                             "_Platform",
-	                                             renderer,
-	                                             "pixbuf", PLATFORM_LIST_COL_LOGO,
-						     NULL);
-
-	/* Insert the text cell */
-	column = gtk_tree_view_get_column (GTK_TREE_VIEW (list), PLATFORM_LIST_COL_LOGO);
-	
-	renderer = gtk_cell_renderer_text_new ();
-	g_object_set (G_OBJECT (renderer), "xalign", 0.0, NULL);
-
-	gtk_tree_view_column_pack_end (column, renderer, TRUE);
-	gtk_tree_view_column_add_attribute (column, renderer, "markup", PLATFORM_LIST_COL_NAME);
-	
-	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (list));
-	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
-
-	g_signal_connect (G_OBJECT (select), "changed",
-			  G_CALLBACK (on_platform_list_selection_changed),
-			  (gpointer) tool);
-}
-
-static void
-gst_tool_populate_platform_list (GstTool *tool)
-{
-	GtkListStore *store;
-	GtkTreeIter iter;
-	GList *platforms, *list;
-	OobsPlatform *platform;
-	GString *str;
-
-	store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (tool->platform_list)));
-	list = platforms = oobs_session_get_supported_platforms (tool->session);
-
-	while (platforms) {
-		platform = platforms->data;
-		platforms = platforms->next;
-
-		str = g_string_new (platform->name);
-
-		if (platform->version)
-			g_string_append_printf (str, " %s", platform->version);
-
-		if (platform->codename)
-			g_string_append_printf (str, " (<i>%s</i>)", platform->codename);
-
-		gtk_list_store_append (store, &iter);
-		gtk_list_store_set (store, &iter,
-		                    PLATFORM_LIST_COL_LOGO, NULL,
-		                    PLATFORM_LIST_COL_NAME, str->str,
-		                    PLATFORM_LIST_COL_ID, platform->id,
-				    -1);
-
-		g_string_free (str, TRUE);
-	}
-
-	g_list_free (list);
-}
-
-
 /*
 static void
 on_remote_hosts_list_selection_changed (GtkTreeSelection *selection, gpointer data)
@@ -1331,7 +1223,9 @@ try_show_usage_warning (void)
 void
 gst_init_tool (const gchar *app_name, int argc, char *argv [], GOptionEntry *entries)
 {
+#ifdef ENABLE_GNOME
 	GnomeProgram   *program;
+#endif
 	GOptionContext *context;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
@@ -1345,18 +1239,22 @@ gst_init_tool (const gchar *app_name, int argc, char *argv [], GOptionEntry *ent
 		g_option_context_parse (context, &argc, &argv, NULL);
 	}
 
+#ifdef ENABLE_GNOME
  	program = gnome_program_init (app_name, VERSION,
 				      LIBGNOMEUI_MODULE, argc, argv,
 				      GNOME_PARAM_APP_DATADIR, DATADIR,
 				      GNOME_PARAM_HUMAN_READABLE_NAME,
 				      _("GNOME System Tools"),
 				      NULL);
-	/* try_show_usage_warning (); */
+#else
+	gtk_init (&argc, &argv);	
+#endif
 }
 
 void
 gst_tool_show_help (GstTool *tool, gchar *section)
 {
+#ifdef ENABLE_GNOME
 	GError    *error = NULL;
 	gchar     *help_file;
 
@@ -1379,6 +1277,7 @@ gst_tool_show_help (GstTool *tool, gchar *section)
 	}
 
 	g_free (help_file);
+#endif
 }
 
 static gboolean
@@ -1432,9 +1331,9 @@ gst_tool_hide_report_window (GstTool *tool)
 }
 
 static void
-on_commit_finalized (OobsObject       *object,
-		     OobsObjectResult  result,
-		     gpointer          data)
+on_commit_finalized (OobsObject *object,
+		     OobsResult  result,
+		     gpointer    data)
 {
 	gst_tool_hide_report_window (GST_TOOL (data));
 }
