@@ -19,7 +19,6 @@
  */
 
 #include <oobs/oobs.h>
-#include <libgnome/gnome-init.h>
 #include <string.h>
 #include "network-locations.h"
 #include <sys/types.h>
@@ -159,6 +158,8 @@ gst_network_locations_class_init (GstNetworkLocationsClass *class)
 			    sizeof (GstNetworkLocationsPrivate));
 }
 
+#define GNOME_DOT_GNOME ".gnome2/"
+
 static gchar*
 create_dot_dir ()
 {
@@ -474,6 +475,7 @@ compare_interface (GObject  *iface,
 
 	  equal = compare_string (value1, value2);
 	  g_free (value1);
+	  g_free (value2);
 	}
       else if (props[i].type == TYPE_INT)
 	{
@@ -491,6 +493,8 @@ compare_interface (GObject  *iface,
       i++;
     }
 
+  g_free (name);
+
   return equal;
 }
 
@@ -606,6 +610,7 @@ set_static_hosts (OobsHostsConfig *hosts_config,
       static_host = oobs_static_host_new (ip_address, list);
       oobs_list_append (static_hosts, &iter);
       oobs_list_set (static_hosts, &iter, static_host);
+      g_object_unref (static_host);
       g_strfreev (split);
 
       elem++;
@@ -664,6 +669,7 @@ set_interface (GObject  *iface,
 	{
 	  value = g_key_file_get_string (key_file, name, props[i].key, NULL);
 	  g_object_set (iface, props[i].key, value, NULL);
+	  g_free (value);
 	}
       else if (props[i].type == TYPE_INT)
 	{
@@ -678,6 +684,8 @@ set_interface (GObject  *iface,
 
       i++;
     }
+
+  g_free (name);
 }
 
 /* FIXME: merge with save_interfaces_list */
@@ -787,7 +795,7 @@ save_static_hosts (OobsHostsConfig *config,
   gboolean valid;
   GObject *static_host;
   GString *str;
-  gchar **arr;
+  gchar **arr, *aliases;
   gint i = 0;
 
   list = oobs_hosts_config_get_static_hosts (config);
@@ -799,17 +807,20 @@ save_static_hosts (OobsHostsConfig *config,
       static_host = oobs_list_get (list, &iter);
 
       str = g_string_new (oobs_static_host_get_ip_address (OOBS_STATIC_HOST (static_host)));
-      g_string_append (str, concatenate_aliases (OOBS_STATIC_HOST (static_host)));
+      aliases = concatenate_aliases (OOBS_STATIC_HOST (static_host));
+      g_string_append (str, aliases);
       arr[i] = str->str;
 
       g_string_free (str, FALSE);
       g_object_unref (static_host);
+      g_free (aliases);
       valid = oobs_list_iter_next (list, &iter);
       i++;
     }
 
   g_key_file_set_string_list (key_file, "general", "static-hosts",
 			      (const gchar**) arr, g_strv_length (arr));
+  g_strfreev (arr);
 }
 
 static void
@@ -818,11 +829,13 @@ save_hosts_config (OobsHostsConfig *config,
 {
   GList *list;
   gchar **arr;
+  const gchar *str;
 
-  g_key_file_set_string (key_file, "general", "hostname",
-			 oobs_hosts_config_get_hostname (config));
-  g_key_file_set_string (key_file, "general", "domainname",
-			 oobs_hosts_config_get_domainname (config));
+  str = oobs_hosts_config_get_hostname (config);
+  g_key_file_set_string (key_file, "general", "hostname", (str) ? str : "");
+
+  str = oobs_hosts_config_get_domainname (config);
+  g_key_file_set_string (key_file, "general", "domainname", (str) ? str : "");
 
   list = oobs_hosts_config_get_dns_servers (config);
   arr = list_to_array (list);
@@ -862,6 +875,7 @@ save_interface (GObject     *iface,
 	{
 	  g_object_get (iface, props[i].key, &value, NULL);
 	  g_key_file_set_string (key_file, name, props[i].key, (value) ? value : "");
+	  g_free (value);
 	}
       else if (props[i].type == TYPE_INT)
 	{
@@ -876,6 +890,8 @@ save_interface (GObject     *iface,
 
       i++;
     }
+
+  g_free (name);
 }
 
 static void
@@ -921,6 +937,7 @@ save_current (GstNetworkLocations *locations,
   GKeyFile *key_file;
   GstNetworkLocationsPrivate *priv;
   gchar *contents, *filename, *path;
+  gboolean retval;
 
   priv = GST_NETWORK_LOCATIONS_GET_PRIVATE (locations);
 
@@ -937,8 +954,13 @@ save_current (GstNetworkLocations *locations,
 
   filename = g_filename_from_utf8 (name, -1, NULL, NULL, NULL);
   path = g_build_filename (priv->dot_dir, filename, NULL);
+  retval = g_file_set_contents (path, contents, -1, NULL);
 
-  return g_file_set_contents (path, contents, -1, NULL);
+  g_free (contents);
+  g_free (filename);
+  g_free (path);
+
+  return retval;
 }
 
 gboolean
